@@ -35,7 +35,6 @@ implementation.
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, print_function
 
 import logging
 import sys
@@ -184,7 +183,7 @@ def init(logfile, force_flush=0, enable_function=0, enable_syslog=0):
             logging.getLogger('ud2').addHandler(_handler_file)
             logging.getLogger('ud2').removeHandler(null_handler)
             result = _handler_file.stream
-        except EnvironmentError as ex:
+        except OSError as ex:
             print('opening %s failed: %s' % (logfile, ex))
 
 #     if enable_syslog:
